//-----------------------------------------------------------------------------
// drawer.m
//
// Example of a simple drawer
//
// created by FrisbeeMonkey
//-----------------------------------------------------------------------------

//                            USING THIS SCRIPT:
//*****************************************************************************
//  1.  Define a drawer group in your XML.
//  2.  Add your background layer to the group, something like:
//        <layer id="Drawer" image="player.Drawer" x="0" y="0" sysregion="1"/>
//        You can change any of the values but the id and sysregion
//  3.  Add a layer to pass info to this script, something like:
//        <layer id="DrawerInfo" x="13" y="0"/>
//        Set x and y to where you want your drawer to slide to
//  3.  Add any other objects(layers, buttons, sliders, etc) to your group
//  4.  Copy this script (and drawer.maki) to your scripts folder.
//  5.  If you don't have drawer.maki, compile this script.
//  6.  Add this line to the group that you want to be a drawer:
//        <script id="drawer" file="scripts/drawer.maki"/>
//  7.  Refresh your skin(F5) and try it out.
//*****************************************************************************

//                               EXAMPLE XML
//=============================================================================
//<groupdef id="DrawerGroup" w="39" h="158"> <!-- 39,0 -->
//
//  <layer id="Drawer" image="player.Drawer" x="0" y="0" sysregion="1" move="0"/>
//  <layer id="DrawerInfo" x="13" y="0"/>
//  //add other objects that you want to move with the drawer here
//
//  <script id="drawer" file="scripts/drawer.maki"/>
//</groupdef>
//=============================================================================
//  ***Don't forget to place your group somewhere in your layout!***
//  <group id="DrawerGroup" x="47" y="0"/>


// never forget to include std.mi
#include "../../../lib/std.mi"

//declares global variables for use in script
Global Group DrawerGrp;
Global Layer Drawer, DrawerInfo;
Global Int DrawerStatus;  //0 = closed, 1 = open
Global Int StartX, StartY, EndX, EndY;

//when the script is loaded, do this
System.onScriptLoaded() {

	//gets the group that has the objects we want
	DrawerGrp = getScriptGroup();;

	//now that we have the group, get the layers in the group
	Drawer = DrawerGrp.findObject("Drawer2");
	DrawerInfo = DrawerGrp.findObject("Drawer2Info");

	StartX = StringToInteger(DrawerGrp.getXMLparam("x"));
	StartY = StringToInteger(DrawerGrp.getXMLparam("y"));
	EndX = StringToInteger(DrawerInfo.getXMLparam("x"));
	EndY = StringToInteger(DrawerInfo.getXMLparam("y"));

	//initialize our drawer flag to closed
	DrawerStatus = 0;

}//end onScriptLoaded()

//when the left mouse button is released within Drawer, do this
Drawer.onLeftButtonUp(int x, int y) {
  if (DrawerStatus == 0) {  // if our Drawer is closed, make it slide open
    if (!DrawerGrp.isGoingToTarget()) {  //makes sure it isn't already moving
      DrawerGrp.setTargetX(EndX);  //set the x coordinate you want the drawer to slide to
      DrawerGrp.setTargetY(EndY);  //set the y coordinate you want the drawer to slide to
      DrawerGrp.setTargetSpeed(1);  //sets the speed the drawer will slide at(higher is slower)
      DrawerGrp.gotoTarget();  //now that we have our target values and speed, start moving!
      DrawerStatus = 1;  //Change the flag to Open
    }
  }
  else {  // if our Drawer is open, make it slide closed
    if (!DrawerGrp.isGoingToTarget()) {  //makes sure it isn't already moving
      DrawerGrp.setTargetX(StartX);  //set the x coordinate you want the drawer to slide back to
      DrawerGrp.setTargetY(StartY);   //set the y coordinate you want the drawer to slide back to
      DrawerGrp.setTargetSpeed(1);  //sets the speed the drawer will slide at(higher is slower)
      DrawerGrp.gotoTarget();  //now that we have our target values and speed, start moving!
      DrawerStatus = 0;  //Change the flag to Closed
    }
  }
}